@@ -148,6 +148,8 @@ L3_AGENT_SCHEDULER_EXT_ALIAS = 'l3_agent_scheduler'
 DHCP_AGENT_SCHEDULER_EXT_ALIAS = 'dhcp_agent_scheduler'
 L3_DISTRIBUTED_EXT_ALIAS = 'dvr'
 L3_HA_MODE_EXT_ALIAS = 'l3-ha'
+L3_ENABLE_DEFAULT_ROUTE_ECMP_ALIAS = 'enable-default-route-ecmp'
+L3_ENABLE_DEFAULT_ROUTE_BFD_ALIAS = 'enable-default-route-bfd'
 SUBNET_ALLOCATION_EXT_ALIAS = 'subnet_allocation'
 
 # Protocol names and numbers for Security Groups/Firewalls
@@ -625,7 +627,7 @@ METADATA_V4_CIDR = '169.254.169.254/32'
 METADATA_V4_SUBNET = '169.254.0.0/16'
 
 METADATA_V6_IP = 'fe80::a9fe:a9fe'
-METADATA_V6_CIDR = 'fe80::a9fe:a9fe/64'
+METADATA_V6_CIDR = 'fe80::a9fe:a9fe/128'
 
 METADATA_PORT = 80
 
