@@ -16,13 +16,9 @@
 TRAIT_PREFIX_VNIC_TYPE = 'VNIC_TYPE_'
 TRAIT_PREFIX_PHYSNET = 'PHYSNET_'
 
-# resource classes
-CLASS_NET_BW_EGRESS_KBPS = 'NET_BW_EGR_KILOBIT_PER_SEC'
-CLASS_NET_BW_INGRESS_KBPS = 'NET_BW_IGR_KILOBIT_PER_SEC'
-
 # Optionally reported inventory parameters. Mandatory parameters like 'total'
 # are left out intentionally. See also:
-# https://developer.openstack.org/api-ref/placement
+# https://docs.openstack.org/api-ref/placement
 #        /#update-resource-provider-inventory
 INVENTORY_OPTIONS = set([
     'allocation_ratio',
